@@ -1,7 +1,3 @@
-# coding: utf-8
-
-from __future__ import unicode_literals, absolute_import
-
 import re
 import textwrap
 import logging
@@ -10,7 +6,7 @@ import logging
 log = logging.getLogger(__name__)
 
 
-class LineBuffer(object):
+class LineBuffer:
     r"""
     Buffer bytes read in from a connection and serve complete lines back.
 
@@ -105,10 +101,12 @@ class DecodingLineBuffer(LineBuffer):
                 self.handle_exception()
 
     def handle_exception(self):
-        msg = textwrap.dedent("""
+        msg = textwrap.dedent(
+            """
             Unknown encoding encountered. See 'Decoding Input'
             in https://pypi.python.org/pypi/irc for details.
-            """)
+            """
+        )
         log.warning(msg)
         raise
 
