@@ -1,16 +1,12 @@
-from __future__ import absolute_import, unicode_literals, print_function
-
 import re
 import itertools
 import textwrap
 import functools
 
-import six
-
 try:
-    from importlib import resources
+    from importlib import resources  # type: ignore
 except ImportError:  # pragma: nocover
-    import importlib_resources as resources
+    import importlib_resources as resources  # type: ignore
 
 from jaraco.functools import compose, method_cache
 
@@ -37,7 +33,7 @@ def multi_substitution(*substitutions):
     return compose(*substitutions)
 
 
-class FoldedCase(six.text_type):
+class FoldedCase(str):
     """
     A case insensitive string class; behaves just like str
     except compares equal when the only variation is case.
@@ -229,7 +225,7 @@ def unwrap(s):
     return '\n'.join(cleaned)
 
 
-lorem_ipsum = resources.read_text(__name__, 'Lorem ipsum.txt')
+lorem_ipsum = resources.read_text(__name__, 'Lorem ipsum.txt')  # type: ignore
 
 
 class Splitter(object):
@@ -257,7 +253,7 @@ def indent(string, prefix=' ' * 4):
 
 class WordSet(tuple):
     """
-    Given a Python identifier, return the words that identifier represents,
+    Given an identifier, return the words that identifier represents,
     whether in camel case, underscore-separated, etc.
 
     >>> WordSet.parse("camelCase")
@@ -335,6 +331,39 @@ class WordSet(tuple):
     def space_separated(self):
         return ' '.join(self)
 
+    def trim_right(self, item):
+        """
+        Remove the item from the end of the set.
+
+        >>> WordSet.parse('foo bar').trim_right('foo')
+        ('foo', 'bar')
+        >>> WordSet.parse('foo bar').trim_right('bar')
+        ('foo',)
+        >>> WordSet.parse('').trim_right('bar')
+        ()
+        """
+        return self[:-1] if self and self[-1] == item else self
+
+    def trim_left(self, item):
+        """
+        Remove the item from the beginning of the set.
+
+        >>> WordSet.parse('foo bar').trim_left('foo')
+        ('bar',)
+        >>> WordSet.parse('foo bar').trim_left('bar')
+        ('foo', 'bar')
+        >>> WordSet.parse('').trim_left('bar')
+        ()
+        """
+        return self[1:] if self and self[0] == item else self
+
+    def trim(self, item):
+        """
+        >>> WordSet.parse('foo bar').trim('foo')
+        ('bar',)
+        """
+        return self.trim_left(item).trim_right(item)
+
     def __getitem__(self, item):
         result = super(WordSet, self).__getitem__(item)
         if isinstance(item, slice):
@@ -381,7 +410,7 @@ def simple_html_strip(s):
     return ''.join(texts)
 
 
-class SeparatedValues(six.text_type):
+class SeparatedValues(str):
     """
     A string separated by a separator. Overrides __iter__ for getting
     the values.
@@ -399,7 +428,7 @@ class SeparatedValues(six.text_type):
 
     def __iter__(self):
         parts = self.split(self.separator)
-        return six.moves.filter(None, (part.strip() for part in parts))
+        return filter(None, (part.strip() for part in parts))
 
 
 class Stripper:
